'use strict';

/**
 * Created by Dio on 2016/8/19.
 */

module.exports = {
    /**
     * @desc 阻止事件冒泡传播
     */
    stopBubble: function stopBubble(event) {
        //如果提供了事件对象，则这是一个非IE浏览器
        if (event && event.stopPropagation) {
            //因此它支持W3C的stopPropagation()方法
            event.stopPropagation();
            event.preventDefault(); // 取消事件的默认行为
        } else {
            //否则，我们需要使用IE的方式来取消事件冒泡
            window.event.cancelBubble = true;
            window.event.returnValue = false; //阻止事件的默认行为
        }
    },
    /**
     * 为nodes节点添加事件
     */
    addEventToNodes: function addEventToNodes(nodes, event, handler) {
        for (var i = 0; i < nodes.length; i++) {
            this.addEvent(nodes[i], event, handler.bind(this), false);
        }
    }
    /**
     * 为nodes节点移除事件
     */
    , removeEventToNodes: function removeEventToNodes(nodes, event, handler) {
        for (var i = 0; i < nodes.length; i++) {
            this.removeEvent(nodes[i], event, handler.bind(this), false);
        }
    }
    /**
     * 添加事件
     * @param ele 要添加事件的DOM节点
     * @param event 要添加事件类型
     * @param handler 要添加事件处理函数
     */
    , addEvent: function addEvent(ele, event, handler) {
        if (!ele) {
            return;
        }
        if (ele.attachEvent) {
            ele.attachEvent('on' + event, handler);
        } else if (ele.addEventListener) {
            ele.addEventListener(event, handler, false);
        } else {
            ele['on' + event] = handler;
        }
    }
    /**
     * 移除事件
     * @param ele 要移除事件的DOM节点
     * @param event 要移除事件类型
     * @param handler 要移除事件处理函数
     */
    , removeEvent: function removeEvent(ele, event, handler) {
        if (!ele) {
            return;
        }
        if (ele.detachEvent) {
            ele.detachEvent('on' + event, handler);
        } else if (ele.removeEventListener) {
            ele.removeEventListener(event, handler, false);
        } else {
            ele['on' + event] = null;
        }
    }
};