'use strict';

var CryptoJS = require('./crypto-js');

var transType = 'NCC';

/**
 * 为全局添加业务信息
 * 如： 业务日期 业务集团信息 用户idsuperSign
 * @param {String} businessDate 业务日期
 * @param {String} userId 用户id
 * @param {String} groupId 集团id
 */
function getBusinessInfo() {
    if (window.top && typeof window.top.GETBUSINESSINFO === 'function') {
        return window.top.GETBUSINESSINFO();
    } else {
        return null;
    }
}

/**
 * 加签处理方法
 * @param data
 * @param userCode
 * @param allin
 * @returns {*}
 */
function addDataSign(data, userCode) {
    var allin = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

    if (typeof transSn === "undefined" || typeof transSign === "undefined" || !userCode) {
        return data;
    }
    // 先加签全部数据 或者部分数据
    var dataStr = JSON.stringify(data);
    // 这里会影响原字符串 （编码、位数？）导致后台解析不了字符串
    var strDataSign = (allin ? dataStr : data.busiParamJson) + "";
    // 加签 -- bbqin
    data.sysParamJson.sn = transSn(userCode);
    data.sysParamJson.signdata = transSign(strDataSign, userCode);
    return data;
}

function transSn(usercode) {
    var result = '';
    if (transType == 'NCC') {
        result = usercode;
    } else {
        //ca根据type判断，type为本文件配置
        throw new Error('需要CA认证，但是未安装相应代码');
    }
    return result;
}

//传输签名一定是不需要密码的
function transSign(value, uid) {
    var result = '';
    if (transType == 'NCC') {
        result = CryptoJS.enc.Base64.stringify(CryptoJS.SHA256(uid + value));
    } else {
        //ca根据type判断，type为本文件配置
        throw new Error('需要CA认证，但是未安装相应代码');
    }
    return result;
}

module.exports.default = { getBusinessInfo: getBusinessInfo, addDataSign: addDataSign, transSign: transSign, transSn: transSn };