'use strict';

var _ReferConstants = require('../constants/ReferConstants');

/**
** 表型参照：由YYReferDialog调用
**/
var React = require('react');
var _ = require('lodash');
var ajax = require('../../../utils/ajax');
var YYClass = require('../../base/YYClass');
var YYTabs = require('../../tabs/YYTabs');
var YYTab = require('../../tabs/YYTab');
var YYIcon = require('../../icon/YYIcon');
var YYRow = require('../../layout/YYRow');
var YYCol = require('../../layout/YYCol');
var YYButton = require('../../button/YYButton');
var YYTable = require('../../table/YYTable');
var YYPagination = require('../../paging/YYPagination');
var YYSelect = require('../../formcontrols/select/YYSelect');
var YYMessage = require('../../message/YYMessage');
var YYScrollbar = require('../../scrollbar/YYScrollbar');
var YYInputButton = require('../../formcontrols/inputbutton/YYInputButton');
var FooterView = require('./FooterView');
var LinkDialogView = require('./LinkDialogView');
var PropTypes = YYClass.PropTypes;
var field = YYClass.field;

var _require = require('react-redux'),
    connect = _require.connect;

var _require2 = require('../actions/reference'),
    getGridData = _require2.getGridData,
    addOften = _require2.addOften,
    deleteOften = _require2.deleteOften,
    loadingReferGrid = _require2.loadingReferGrid,
    saveInnerFilterObject = _require2.saveInnerFilterObject,
    delInnerFilterObject = _require2.delInnerFilterObject;

require('../style/index.less');
var AuthToken = require("../../../utils/AuthToken");
var DataUtil = require('../../../utils/DataUtil');
// var pageSize = 10;
var store = window.localStorage;
var tableKey = null;
var charCode = String.fromCharCode(2);

var _require3 = require('../utils/YYReferUtils'),
    getColumns = _require3.getColumns,
    ifInArray = _require3.ifInArray,
    removeRow = _require3.removeRow,
    getPagination = _require3.getPagination,
    sortWithTableRows = _require3.sortWithTableRows,
    getDefaultRows = _require3.getDefaultRows,
    getDefaultKeys = _require3.getDefaultKeys,
    getHeaders = _require3.getHeaders,
    formatOftenToServer = _require3.formatOftenToServer,
    formatOftenFromServer = _require3.formatOftenFromServer,
    getOftenKeys = _require3.getOftenKeys;

var mapStateToProps = function mapStateToProps(state) {
	return {
		refinfo: state.refinfo,
		loadingReferGrid: state.refinfo.loadingReferGrid,
		innerFilterObject: state.refinfo.innerFilterObject
	};
};

function noop() {};
//定义META
var uiMeta = {
	name: 'refer-grid',
	fields: [
	//field参数列表：字段属性名|属性默认值|属性类型|是否必填|属性描述
	field('refinfokey', null, PropTypes.string, true, '参照key'), field('refname', null, PropTypes.string, true, '参照名称'), field('dataurl', null, PropTypes.string, true, '查询url'), field('operateurl', null, PropTypes.string, true, '操作url'), field('initialValue', null, PropTypes.oneOfType([PropTypes.object, PropTypes.Array]), false, '默认初始值'), field('orderfield', null, PropTypes.string, true, '排序字段'), field('often', false, PropTypes.bool, true, '是否显示常用(已失效)'), field('multiselect', null, PropTypes.bool, true, '是否支持多选'), field('querystr', null, PropTypes.string, true, '查询条件(已过期-推荐使用condition属性)'), field('condition', null, PropTypes.oneOfType([PropTypes.func, PropTypes.object]), true, '自定义查询条件'), field('onOk', null, PropTypes.func, true, '确认操作回调函数'), field('onCancel', null, PropTypes.func, true, '取消操作回调函数'), field('customheader', null, PropTypes.element, false, '自定义header'), field('contentH', null, PropTypes.number, true, '内容区域的高度'), field('gridheaders', null, PropTypes.array, false, '表头信息'), field('searchPlaceholder', null, PropTypes.string, false, '搜索框显示信息'), field('rowClickCheckable', true, PropTypes.bool, false, 'checkable启用时，点击行是否同时触发点击勾选框')]
};
var YYReferGrid = YYClass.create({
	uiMeta: uiMeta,
	tableData: null,
	getInitialState: function getInitialState() {
		return {
			current: 1,
			refid: null,
			name: null,
			// loadOften : false ,
			selectedRow: this.props.multiselect ? null : getDefaultRows(this.props.initialValue, this.props.idField, this.props.codeField, this.props.nameField, this.props.multiselect), //单选row
			selectedRowKey: this.props.multiselect ? null : getDefaultKeys(this.props.initialValue, this.props.multiselect), //单选key,多选模式下不获取
			selectedRows: this.props.multiselect ? getDefaultRows(this.props.initialValue, this.props.idField, this.props.codeField, this.props.nameField, this.props.multiselect) : null, //多选rows
			selectedRowKeys: this.props.multiselect ? getDefaultKeys(this.props.initialValue, this.props.multiselect) : null, //多选keys, 单选模式下不获取
			searchVal: null,
			searchInputValue: null,
			showOperateDialog: false, //是否打开operate dialog
			operateurl: null //operate的url
		};
	},
	componentWillMount: function componentWillMount() {
		var _props = this.props,
		    refinfokey = _props.refinfokey,
		    pageSize = _props.pageSize;

		if (store) {
			var userCode = AuthToken.getUserCode();
			tableKey = _ReferConstants.REFER_TABLEKEY + userCode + "-" + refinfokey;
			//优先从pageSize获取
			var pageSizeBefore = YYTable.getLocalPageSize(tableKey);
			// 当打开参照，并且本地无pagesize记录时，以参照注册信息中的pagesize为准，
			// 或者当pageSize发生改变时
			var currPageSize = pageSize != undefined && pageSize != null ? pageSize : pageSizeBefore;

			YYTable.setLocalPageSize(tableKey, currPageSize ? currPageSize : 10);
		}
	},
	componentWillUnmount: function componentWillUnmount() {
		this.props.dispatch(delInnerFilterObject(this.props.refcode));
	},
	componentDidMount: function componentDidMount() {
		var that = this;
		// 延迟，解决tab错位的bug
		this.props.dispatch(loadingReferGrid(true));
		setTimeout(function () {
			that.doQuery(null, 1);
		}, 500);
	},
	componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
		if (nextProps && nextProps.refinfo) {
			var refinfo = nextProps.refinfo;
			if (refinfo.doReload) {
				//重新查询数据
				this.doQuery(null, 1);
				// this.refs.inputSearch.state.value = '';
				this.setState({
					current: 1,
					searchVal: '',
					searchInputValue: ''
				});
			}
			if (refinfo.showMsg) {
				var showMsg = refinfo.showMsg;
				if (showMsg.success) {
					YYMessage.success(showMsg.success);
				} else if (showMsg.error) {
					YYMessage.error(showMsg.error);
				}
			}
		}
	},

	// changeTags(key){
	// 	this.setState({
	// 		loadOften : !this.state.loadOften,
	// 	});
	// },
	// // 保存/删除 常用数据到服务器. oper=0: 手动， oper=1：自动
	// _saveOften(records, oper, isDelete){
	// 	var dispatch = this.props.dispatch;
	// 	var userId = AuthToken.getUserId();
	// 	var refinfokey = this.props.refinfokey;
	// 	var idField = this.props.idField;
	// 	var serverUrl = this.props.serverUrl;
	// 	if(isDelete === true){
	// 		var ids = records[idField];// 当前删除只支持单个删除，后续支持批量删除后在此扩展
	// 		dispatch(deleteOften(serverUrl,{userId, refinfokey, ids}));
	// 	}else{
	// 		var dataset = formatOftenToServer(records, idField);
	// 		if(dataset && dataset.length >0){
	// 			dispatch(addOften(serverUrl,{userId, refinfokey, oper:oper, dataset}))
	// 		}
	// 	}
	// },
	// //添加常用
	// addOften(record,e){
	// 	e.stopPropagation();
	// 	if(store && record){
	// 		var nodeKey = record[this.props.idField];
	// 		this._saveOften(record, 0);
	// 	}
	// 	this.setState({
	// 		loadOften : !this.state.loadOften,
	// 	});
	// },
	// // 删除常用
	// delOften(record,e){
	// 	e.stopPropagation();
	// 	var nodeKey = record[this.props.idField];
	// 	var isDelete = true;// 便于理解和维护。此处用于标识删除操作
	// 	this._saveOften(record,null,isDelete);
	// 	this.setState({
	// 		loadOften : !this.state.loadOften,
	// 	});
	// },
	//取消
	onCancelHandle: function onCancelHandle(e) {
		if (this.props.onCancel) {
			this.props.onCancel(e);
		}
	},

	// 清除已选择的数据
	onClean: function onClean() {
		this.setState({
			selectedRow: null,
			selectedRowKey: null,
			selectedRows: null,
			selectedRowKeys: null
		});
	},

	// 刷新按钮
	onRefresh: function onRefresh() {
		this.setState({
			current: 1,
			searchInputValue: null
		});
		this.componentDidMount();
	},

	//设置查询条件
	getQuery: function getQuery(querystr, condition, searchText, orderfield, pageNumber, pageSize) {
		var getQuery = {};
		if (pageSize !== -1) {
			getQuery.pageSize = pageSize ? pageSize : YYTable.getDefaultPageSize(tableKey);
			getQuery.pageNumber = pageNumber;
		}
		if (querystr && querystr.length > 0) getQuery.relyCondition = querystr;
		if (orderfield && orderfield.length > 0) getQuery.orderCondition = orderfield;
		if (searchText && searchText.length > 0) getQuery.searchText = searchText;
		var _condition = ajax.getParams(condition);
		if (!_.isEmpty(_condition) && _.isPlainObject(_condition)) {
			//转成JSON格式字符串
			getQuery.condition = JSON.stringify(_condition);
		}
		return getQuery;
	},

	//执行查询动作
	doQuery: function doQuery(searchVal, current, pageSize) {
		var _props2 = this.props,
		    refcode = _props2.refcode,
		    dataurl = _props2.dataurl,
		    querystr = _props2.querystr,
		    condition = _props2.condition,
		    orderfield = _props2.orderfield,
		    refid = _props2.refid,
		    queryMethod = _props2.queryMethod,
		    innerFilterObject = _props2.innerFilterObject,
		    dispatch = _props2.dispatch,
		    technicalType = _props2.technicalType,
		    queryCondition = _props2.queryCondition;

		pageSize = pageSize ? pageSize : YYTable.getDefaultPageSize(tableKey);
		var getQuery = this.getQuery(querystr, condition, searchVal, orderfield, current, pageSize);
		var searchObject = _.isObject(innerFilterObject) ? innerFilterObject['' + refcode] : {};
		dispatch(getGridData(dataurl, getQuery, null, { queryMethod: queryMethod, searchObject: searchObject, technicalType: technicalType, queryCondition: queryCondition }));
	},

	//页码更改
	onChangePage: function onChangePage(current) {
		this.doQuery(this.state.searchVal, current);
		this.setState({
			current: current
		});
	},

	//每页显示的条数更改
	onChangePageSize: function onChangePageSize(current, pageSize) {
		this.doQuery(this.state.searchVal, current, pageSize);
		this.setState({
			current: current
		});
	},

	//搜索
	onSearch: function onSearch(e) {
		var value = e;
		if (_.isObject(e)) {
			value = e.target.value;
		}
		if (this.props.loadingReferGrid) {
			return;
		} else {
			this.doQuery(value, 1);
			this.setState({
				current: 1,
				searchVal: value,
				searchInputValue: value
			});
		}
	},

	//改变搜索栏输入的值
	onChangeSearchValue: function onChangeSearchValue(e, value) {
		this.setState({
			searchInputValue: value
		});
	},

	// 公共方法，确定时调用
	doHandleDatas: function doHandleDatas(selectedRows, selectedRow, isHandleOk) {
		var multiselect = this.props.multiselect;

		var row = null;
		if (multiselect) {
			row = selectedRows ? selectedRows : this.state.selectedRows;
		} else {
			row = selectedRow ? selectedRow : this.state.selectedRow;
		}
		if (isHandleOk) {
			// if(this.props.often){
			// 	this._saveOften(row, 1);
			// }
			this.props.onOk(row);
		} else {
			this.props.onSelectedChanged(row);
		}
	},

	//获取所选数据API：调用者根据this.refs.设置的ref名.getCurrentSelected来获取数据
	getCurrentSelected: function getCurrentSelected() {
		var state = this.state;
		return {
			fullValue: this.props.multiselect ? state.selectedRows : state.selectedRow
		};
	},

	//点击确定
	onOkHandle: function onOkHandle(e) {
		this.doHandleDatas(null, null, true);
	},

	//表格事件
	onChangeRow: function onChangeRow(keys, rows) {
		var selectedRows = this.state.selectedRows ? this.state.selectedRows : [];
		var selectedRowKeys = this.state.selectedRowKeys ? this.state.selectedRowKeys : [];
		if (rows) {
			var sortedRows = sortWithTableRows(rows, this.tableData.props.dataSource, this.tableData.props.pagination.current);
			for (var i = 0; i < sortedRows.length; i++) {

				if (!ifInArray(selectedRowKeys, rows[i][this.props.idField])) {
					//确定当前元素插入的位置index
					var index = 0;
					if (sortedRows.indexOf(sortedRows[i]) == 0) {
						index = 0;
					} else {
						index = selectedRowKeys.indexOf(selectedRowKeys[i - 1]) + 1;
					}
					//根据页数推算出当前元素的位置indexByPage
					var indexByPage = 0;
					if (sortedRows[i].pageCurrent == 1) {
						indexByPage = 0;
					} else {
						for (var t = 0; t < selectedRows.length; t++) {
							// console.log(sortedRows[t].pageCurrent, selectedRows[t].pageCurrent)
							if (sortedRows[i].pageCurrent > selectedRows[t].pageCurrent) indexByPage++;else break;
						}
					}
					//元素的具体位置是index+indexByPage
					selectedRowKeys.splice(index + indexByPage, 0, sortedRows[i][this.props.idField]);
					selectedRows.splice(index + indexByPage, 0, sortedRows[i]);
					// selectedRowKeys.push(rows[i][this.props.idField]);
					// selectedRows.push(rows[i]);
				};
			}
		} else {
			selectedRows = null;
		}
		this.setState({
			selectedRows: selectedRows,
			selectedRowKeys: selectedRowKeys
		});
		this.doHandleDatas(selectedRows, null, false);
	},

	// 表格事件
	onSelectRow: function onSelectRow(record, selected, selectRows) {
		var selectedRows = this.state.selectedRows ? this.state.selectedRows : [];
		var selectedRowKeys = this.state.selectedRowKeys ? this.state.selectedRowKeys : [];
		var key = record[this.props.idField];
		if (!selected) {
			selectedRowKeys.indexOf(key) > -1 ? selectedRowKeys.splice(selectedRowKeys.indexOf(key), 1) : null;
			selectedRows = removeRow(selectedRows, key, this.props.idField);
		} else {
			var _this = this;
			if (selectedRowKeys.indexOf(key) < 0) {
				selectedRowKeys.push(key);
				selectedRows.push(record);
			}
			// _.forEach(selectRows,function (item) {
			//     selectedRowKeys.push(item[_this.props.idField])
			// })
		}
		this.setState({
			selectedRows: selectedRows,
			selectedRowKeys: selectedRowKeys
		});
		this.doHandleDatas(selectedRows, null, false);
	},

	//全选
	onSelectAllRow: function onSelectAllRow(selected, selectRows, changeRows) {
		var selectedRows = this.state.selectedRows ? this.state.selectedRows : [];
		var selectedRowKeys = this.state.selectedRowKeys ? this.state.selectedRowKeys : [];
		if (!selected) {
			for (var i = changeRows.length - 1; i >= 0; i--) {
				var key = changeRows[i][this.props.idField];
				selectedRowKeys.indexOf(key) > -1 ? selectedRowKeys.splice(selectedRowKeys.indexOf(key), 1) : null;
				selectedRows = removeRow(selectedRows, key, this.props.idField);
			};
		} else {
			for (var i = changeRows.length - 1; i >= 0; i--) {
				var key = changeRows[i][this.props.idField];
				if (selectedRowKeys.indexOf(key) < 0) {
					selectedRowKeys.push(key);
					selectedRows.push(changeRows[i]);
				}
			}
			// var _this = this
			// // selectedRowKeys = []
			// selectedRows = selectRows
			// _.forEach(selectRows,function (item) {
			// selectedRowKeys.push(item[_this.props.idField])
			// })
		}
		this.setState({
			selectedRows: selectedRows,
			selectedRowKeys: selectedRowKeys
		});
		this.doHandleDatas(selectedRows, null, false);
	},

	//选中行 单选时
	onRowClick: function onRowClick(record, index) {
		this.setState({
			selectedRow: record,
			selectedRowKey: record[this.props.idField]
		});
		this.doHandleDatas(null, record, false);
	},

	// 选中行 双击时 单选时
	onRowDoubleClick: function onRowDoubleClick(record, index) {
		this.doHandleDatas(null, record, true);
	},

	//关闭标签
	onTagClose: function onTagClose(key) {
		var selectedRows = this.state.selectedRows;
		var selectedRowKeys = this.state.selectedRowKeys;
		selectedRowKeys.indexOf(key) > -1 ? selectedRowKeys.splice(selectedRowKeys.indexOf(key), 1) : null;
		removeRow(selectedRows, key, this.props.idField);
		this.setState({
			selectedRows: selectedRows,
			selectedRowKeys: selectedRowKeys
		});
		this.doHandleDatas(selectedRows, null, false);
	},

	//点击带链接字段
	onClickOperate: function onClickOperate(record, e) {
		if (record) {
			var url = this.props.operateurl + record[this.props.idField];
			var linkUrl = _.find(this.props.gridheaders, { id: e.currentTarget.id });
			linkUrl = linkUrl.linkUrl + record[this.props.idField];
			if (this.props.operateurl) this.setState({
				showOperateDialog: true,
				operateurl: url
			});
			if (linkUrl) this.setState({
				showOperateDialog: true,
				operateurl: linkUrl
			});
		}
	},

	//关闭点击链接打开的dialog回调
	onCloseOperate: function onCloseOperate() {
		this.setState({
			showOperateDialog: false
		});
	},

	dealData: function dealData(data) {
		var arr = [];
		for (var i = 0; i < data.length; i++) {
			var row = data[i];
			arr.push(row);
			if (Array.isArray(row.children) && row.children.length > 0) {
				var subArr = this.dealData(row.children);
				arr = arr.concat(subArr);
			}
		}
		return arr;
	},

	// 内嵌行筛选行回车事件
	onInnerFilterPressEnter: function onInnerFilterPressEnter() {
		this.doQuery(null, this.state.current);
	},

	// 内嵌行筛选值改变事件
	onInnerFilterChange: function onInnerFilterChange(dataIndex, event) {
		var refCode = this.props.refcode;
		if (event && event.target) {
			var data = {};
			data['' + refCode] = {};
			data['' + refCode]['' + dataIndex] = event.target.value;
			this.props.dispatch(saveInnerFilterObject(data));
		}
	},

	//渲染标签页
	_renderContent: function _renderContent() {
		var _this2 = this;

		var that = this;
		var _props3 = this.props,
		    refinfo = _props3.refinfo,
		    refname = _props3.refname,
		    multiselect = _props3.multiselect,
		    tableColRender = _props3.tableColRender,
		    technicalType = _props3.technicalType;

		var grid = refinfo.grid;
		var header = getHeaders(that.props.gridheaders, grid);

		var columnsInStore = getColumns(header, store, this.props.nameField, this.props.operatefield, this.props.operateurl, this.onClickOperate, this.props.innerFilterColumns);
		var totalWidth = columnsInStore.totalWidth;

		var griddata = grid ? grid.data : null;
		var totalsize = griddata ? griddata.count : 0; //总数量
		var content = griddata ? griddata.content : null;
		var data = [];
		if (content && content.length > 0) {
			data = content;
			//很多项目中直接写死，调用了key，必须给key赋值
			// data = this.dealData(data); // xg注释掉,这行代码有毒，树形结构数据会被拉平，导致表格的dataSource放大N倍
			data.map(function (elem, eindex) {
				elem.key = elem[_this2.props.idField];
			});
		};
		var rowSelection = null;
		if (multiselect) {
			rowSelection = {
				onChange: this.onChangeRow,
				onSelect: this.onSelectRow,
				onSelectAll: this.onSelectAllRow,
				selectedRowKeys: this.state.selectedRowKeys
			};

			totalWidth += _ReferConstants.REFER_CHECKBOX_WIDTH;
		};
		var tableH = this.props.contentH - 28 - 45 - 10; //28是表格上方搜索框的高度、45是分页的高度，10是marginTop
		var pagination = false;
		if (this.props.pageSize !== -1) {
			pagination = getPagination(totalsize, that.state.current, that.onChangePage, that.onChangePageSize);
			if (technicalType === "ncc") {
				// ps: 这里改动是因为ncc参照请求后端分页bug及返回的数据无总数
				pagination.showTotal = false;
				pagination.showSizeChanger = false;
			}
		}
		var columns = columnsInStore.columns;
		// 内嵌行筛选绑定事件
		_.forEach(columns, function (column) {
			if (column.innerFilter == true) {
				column.innerFilterProps = {
					onPressEnter: that.onInnerFilterPressEnter.bind(that, column.dataIndex),
					onChange: that.onInnerFilterChange.bind(that, column.dataIndex) };
			}
			if (tableColRender && tableColRender[column.key]) {
				column.render = tableColRender[column.key];
			}
		});
		// var oftenTab = null;
		// if(this.props.often){
		// 	var oftenData = formatOftenFromServer(this.props.refinfo.often);
		// 	var oftenkeys = getOftenKeys(this.props.refinfo.often);
		// 	var oftenColumns = columnsInStore.oftenColumns;
		// 	columns.push({
		// 		key: 'operation',
		// 		title : REFER_ADD_OFTEN,
		// 		width : REFER_OPERATE_COLUMN_WIDTH,
		// 		render: (text, record) => (
		// 			ifInArray(oftenkeys, record[this.props.idField])?
		// 				(<YYButton icon="minus" ghost onClick = {this.delOften.bind(null,record)}></YYButton>):
		// 				(<YYButton icon="plus" ghost onClick = {this.addOften.bind(null,record)}></YYButton>)
		// 		),
		// 	});
		// 	oftenColumns.push({
		// 		key: 'operationOften',
		// 		title : REFER_DELETE_OFTEN,
		// 		width : REFER_OPERATE_COLUMN_WIDTH,
		// 		render: (text, record) => (
		// 			<YYButton icon="minus" ghost onClick = {this.delOften.bind(null,record)}></YYButton>
		// 		)
		// 	});
		//
		// 	totalWidth += REFER_OPERATE_COLUMN_WIDTH;
		// 	oftenTab = <YYTab key={refname+"_often"} tab="常用" disabled = {!this.props.often} className='yyui-refer-tab'>
		// 			<YYTable
		// 				style={{marginTop:5}}
		// 				columns={oftenColumns}
		// 				pagination={false}
		// 				bordered={true}
		// 				rowKey = {that.props.idField}
		// 				dataSource={oftenData}
		// 				scroll={{ x: totalWidth,y:this.props.contentH }}//table下分页的高度
		// 				rowActiveKey={that.state.selectedRowKey}
		// 				rowSelection = {rowSelection}
		// 				onRowDoubleClick={multiselect?noop:this.onRowDoubleClick}
		// 				onRowClick = {multiselect?noop:this.onRowClick}
		// 				rowClickCheckable={this.props.rowClickCheckable}/>
		// 		</YYTab>;
		//
		// }
		var searchCompDisplay = this.props.innerFilter == true ? "none" : "block";
		var dataView = React.createElement(
			'div',
			null,
			this.props.customheader,
			React.createElement(
				'div',
				{ className: 'yyui-refer-grid-search', style: { display: searchCompDisplay } },
				React.createElement(YYInputButton, { ref: 'inputSearch', value: this.state.searchInputValue, onChange: this.onChangeSearchValue, placeholder: that.props.searchPlaceholder, buttonIcon: 'search', onPressEnter: this.onSearch, buttonClick: this.onSearch })
			),
			React.createElement(YYTable, {
				ref: function ref(refComponent) {
					_this2.tableData = refComponent;
				},
				style: { marginTop: 5 },
				cookieKey: tableKey,
				columns: columns,
				loading: this.props.loadingReferGrid,
				pagination: pagination,
				rowKey: that.props.idField,
				dataSource: data,
				bordered: true,
				scroll: { x: totalWidth, y: tableH - _ReferConstants.REFER_TABLE_PAGINATION_HEIGHT },
				rowActiveKey: that.state.selectedRowKey,
				onRowDoubleClick: multiselect ? noop : this.onRowDoubleClick,
				onRowClick: multiselect ? noop : this.onRowClick,
				rowSelection: rowSelection,
				rowClickCheckable: this.props.rowClickCheckable
			})
		);
		// var dataTab = <YYTab key={refname+"_data"} tab={refname} className='yyui-refer-tab'>
		// 		{dataView}
		// 	</YYTab>;
		// if(oftenTab !== null){
		// 	return (
		// 		<YYTabs defaultActiveKey={refname+"_data"} onChange={this.changeTags}>
		// 			{oftenTab}
		// 			{dataTab}
		// 		</YYTabs>
		// 	);
		// }else{
		return dataView;
		// }
	},

	//渲染底部栏
	_renderFooter: function _renderFooter() {
		var props = {};
		props.refname = this.props.refname;
		props.multiselect = this.props.multiselect;
		props.idField = this.props.idField;
		props.nameField = this.props.nameField;
		props.codeField = this.props.codeField;
		props.onOk = this.onOkHandle;
		props.onCancel = this.onCancelHandle;
		props.onClean = this.onClean;
		props.onRefresh = this.onRefresh;
		props.onTagClose = this.onTagClose;
		props.selectedDatas = this.state.selectedRows;
		props.refinfokey = this.props.refinfokey;
		props.customButtons = this.props.customButtons;
		return React.createElement(FooterView, props);
	},
	render: function render() {
		var that = this;
		return React.createElement(
			'div',
			{ className: this.className() },
			this._renderContent(),
			this._renderFooter(),
			React.createElement(LinkDialogView, { visible: that.state.showOperateDialog, url: that.state.operateurl, onCancel: that.onCloseOperate })
		);
	}
});
module.exports = connect(mapStateToProps, null, null, { withRef: true })(YYReferGrid);