'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * 表格配置列组件
 */
var React = require('react');

var _require = require('antd'),
    Select = _require.Select;

var Option = Select.Option;
var _ = require('lodash');
var YYClass = require('../base/YYClass');
var PropTypes = YYClass.PropTypes;
var field = YYClass.field;
var YYModal = require('../modal/YYModal');
var YYForm = require('../formcontrols/form/YYForm');
var YYFormItem = require('../formcontrols/form/YYFormItem');
var YYRow = require('../layout/YYRow');
var YYCol = require('../layout/YYCol');
var Table = require('./override/AntdTable');
var YYSwitch = require('../formcontrols/switch/YYSwitch');
var YYMessage = require('../message/YYMessage');
var YYInputNumber = require('../formcontrols/inputnumber/YYInputNumber');
var YYButton = require('../button/YYButton');
var TreeUtils = require('../../utils/TreeUtils');
var ColumnConfigUtils = require('./utils/ColumnConfigUtils');
var YYTitleGroup = require('./YYTitleGroup');
require('./style/index.less');

//定义META
var uiMeta = {
    name: 'icon',
    fields: [
    //field参数列表：字段属性名|属性默认值|属性类型|是否必填|属性描述
    field('columns', [], PropTypes.array, true, '允许进行配置的表格原始列定义'), field('onOk', null, PropTypes.func, false, '点击确定后的回调,传递参数：configColumns-配置后的列定义'), field('onCancel', null, PropTypes.func, false, '点击取消后的回调'), field('onRevert', null, PropTypes.func, false, '点击还原配置后的回调'), field('visible', false, PropTypes.bool, false, '是否显示配置窗口'), field('isTitleGroup', false, PropTypes.bool, false, '是否是多表头配置')]
};

var YYColumnConfig = YYClass.create({
    uiMeta: uiMeta,
    getInitialState: function getInitialState() {
        var _props = this.props,
            columns = _props.columns,
            scroll = _props.scroll,
            isTitleGroup = _props.isTitleGroup;

        var configColumns = _.cloneDeep(columns);
        if (isTitleGroup) {
            ColumnConfigUtils.initGroupColumnInfo(configColumns);
        }
        var configScroll = _.cloneDeep(scroll);
        return {
            disableTableHeight: !configScroll || _.isEmpty(configScroll) || configScroll["y"] == false,
            configScroll: configScroll,
            configColumns: configColumns,
            dataSource: this._columnsToDataSource(configColumns)
        };
    },

    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        //当配置页面重新打开时，依据columns初始化配置信息
        if (this.props.visible !== nextProps.visible && nextProps.visible == true) {
            var configColumns = _.cloneDeep(nextProps.columns);
            var isTitleGroup = nextProps.isTitleGroup;
            if (isTitleGroup != true) {
                var groupColumns = _.filter(configColumns, function (column) {
                    return column.titleGroup && column.titleGroup.length;
                });
                isTitleGroup = groupColumns && groupColumns.length;
            }
            if (isTitleGroup) {
                ColumnConfigUtils.initGroupColumnInfo(configColumns);
            }
            this.setState({
                isTitleGroup: isTitleGroup,
                configColumns: configColumns,
                dataSource: this._columnsToDataSource(configColumns)
            });
        }
    },

    _onCellChange: function _onCellChange(record, index, dataIndex, event) {
        var configColumns = this.state.configColumns;
        var column = _.find(configColumns, ['dataIndex', record.colIndex ? record.colIndex : record.refRootDataIndex]);
        if (dataIndex == 'colShow') {
            //处理自定义显示状态
            record.colShow = event;
            configColumns = _.map(configColumns, function (col) {
                if (record.colIndex == col.dataIndex) {
                    col.isShow = event;
                }
                return col;
            });
            configColumns = ColumnConfigUtils.groupByFixed(configColumns);
            if (record.colCombine == true) {
                // 多表头合并列
                var nodes = TreeUtils.findWithPropName(column.titleGroup, 'refRootDataIndex', record.colIndex, true, false);
                if (nodes && nodes.length) {
                    _.forEach(nodes, function (node) {
                        var column = _.find(configColumns, ['dataIndex', node.refDataIndex]);
                        if (column) {
                            column.isShow = event;
                        }
                    });
                }
            }
        } else if (dataIndex == 'colWidth') {
            //处理自定义列宽度
            record.colWidth = event;
            configColumns = _.map(configColumns, function (col) {
                if (record.colIndex == col.dataIndex || record.refDataIndex == col.dataIndex) {
                    col.width = event;
                }
                return col;
            });
            // 多表头被合并列
            if (column && column.titleGroup && column.titleGroup.length) {
                var node = TreeUtils.findWithPropName(column.titleGroup, 'refDataIndex', record.refDataIndex, true, true);
                if (node && node.length) {
                    node[0].width = event;
                }
            }
        } else if (dataIndex == 'colFixed') {
            // 处理自定义列冻结
            var colFixed = event === 'none' ? undefined : event;
            record.colFixed = colFixed;
            configColumns = _.map(configColumns, function (col) {
                if (record.colIndex == col.dataIndex) {
                    col.fixed = colFixed;
                }
                return col;
            });
            configColumns = ColumnConfigUtils.groupByFixed(configColumns);
        }
        this.setState({ configColumns: configColumns, dataSource: this._columnsToDataSource(configColumns) });
    },

    //将列定义转换为行配置项
    _columnsToDataSource: function _columnsToDataSource(columns) {
        var dataSource = _.map(columns, function (col, index) {
            return {
                colIndex: col.dataIndex,
                colName: col.title,
                colWidth: col.width,
                colShow: col.isShow === undefined ? true : col.isShow,
                colFixed: col.fixed
            };
        });
        if (this.props.isTitleGroup) {
            dataSource = this._columnsToDataSourceMultiCol(columns, dataSource);
        }
        return dataSource;
    },
    // 对列定义重新排序
    sortColumns: function sortColumns(dataSource, columns) {
        if (!dataSource || _.isEmpty(dataSource) || !columns || _.isEmpty(columns)) {
            return columns;
        }
        dataSource = _.filter(dataSource, function (row) {
            return !row.refDataIndex || row.refDataIndex !== row.refRootDataIndex;
        });
        var retColumns = [];
        _.forEach(dataSource, function (data) {
            var column = _.find(columns, ['dataIndex', data.colIndex ? data.colIndex : data.refDataIndex]);
            if (column) {
                retColumns.push(column);
            }
        });
        return retColumns;
    },

    _loopTitleGroup: function _loopTitleGroup(columns, parentName, colIndex, version) {
        var _this2 = this;

        var dataSource = [];
        _.forEach(columns, function (col, groupIndex) {
            if (col.children && col.children.length) {
                dataSource = dataSource.concat(_this2._loopTitleGroup(col.children, parentName + '/' + col.title));
            } else {
                dataSource.push({
                    colIndex: col.dataIndex,
                    colName: parentName ? parentName + '/' + col.title : col.title,
                    colWidth: col.width,
                    colShow: col.isShow === undefined ? true : col.isShow,
                    colFixed: col.fixed,
                    groupIndex: groupIndex,
                    parentName: parentName,
                    refDataIndex: col.refDataIndex,
                    refRootDataIndex: col.refRootDataIndex,
                    showConfigDisabled: true, // 暂不支持被合并列显示隐藏配置
                    version: version
                });
            }
        });
        return dataSource;
    },
    // 多表头情况
    _columnsToDataSourceMultiCol: function _columnsToDataSourceMultiCol(columns, dataSource, parentName) {
        var _this3 = this;

        // 过滤掉被合并的字段
        columns = _.filter(columns, function (col) {
            return col.colSpan > 0 && col.titleGroup && col.titleGroup.length || col.colSpan != 0;
        });
        var dataSourceMuti = [];
        _.forEach(columns, function (col, groupIndex) {
            var colTitle = col.titleGroup && col.titleGroup.length > 0 ? col.titleGroup[0].title : col.title;
            dataSourceMuti.push({
                colIndex: col.dataIndex,
                colName: parentName ? parentName + '/' + colTitle : colTitle,
                colWidth: col.width,
                colShow: col.isShow === undefined ? true : col.isShow,
                colFixed: col.fixed,
                colCombine: col.titleGroup && col.titleGroup.length,
                groupIndex: groupIndex //用来指定在每个父级字段下的顺序
            });
            if (col.titleGroup && col.titleGroup.length) {
                _.forEach(col.titleGroup, function (childCol) {
                    dataSourceMuti = dataSourceMuti.concat(_this3._loopTitleGroup(childCol.children, childCol.title, groupIndex, childCol.version));
                });
            }
        });
        return dataSourceMuti;
    },

    _handleOk: function _handleOk() {
        var _this = this;
        var form = this.props.form;
        if (form) {
            form.validateFields(function (errors, values) {
                if (!!errors) {
                    return false;
                }
                var enableTableHeight = values["enableTableHeight"] === undefined ? false : values["enableTableHeight"];
                var tableHeight = values["tableHeight"];
                if (enableTableHeight && (!tableHeight || tableHeight === 0)) {
                    YYMessage.error("启用表格宽度限制时, 必须明确设置宽度值!", 3);
                    return false;
                }
                var configColumns = _this.state.configColumns;

                for (var i = 0; i < configColumns.length; i++) {
                    if (configColumns[i].fixed && !configColumns[i].width) {
                        YYMessage.error("【" + configColumns[i].uititle + "】为固定显示列，必须设置明确的宽度值(不能为自动)！", 3);
                        return;
                    }
                }
                var scroll = {};
                if (enableTableHeight && tableHeight) {
                    scroll.y = tableHeight;
                } else {
                    scroll.y = false;
                }
                if (_.isFunction(_this.props.onOk)) {
                    _this.props.onOk(_this.state.configColumns, scroll);
                }
            });
        }
    },
    _handleCancel: function _handleCancel() {
        if (_.isFunction(this.props.onCancel)) {
            this.props.onCancel();
        }
    },
    _handleRevert: function _handleRevert() {
        if (_.isFunction(this.props.onRevert)) {
            this.props.onRevert();
        }
    },
    _exChangeTitleGroupElement: function _exChangeTitleGroupElement(tree, ele1, ele2) {
        var parentTree = TreeUtils.findParentNode(tree, ele1.nid);
        var index1 = _.findIndex(parentTree.children, { 'nid': ele1.nid });
        var index2 = _.findIndex(parentTree.children, { 'nid': ele2.nid });
        var arrays = parentTree.children;
        var _ref = [arrays[index2], arrays[index1]];
        arrays[index1] = _ref[0];
        arrays[index2] = _ref[1];
    },
    //处理列显示顺序
    _handleMove: function _handleMove(record, index, moveType) {
        var _state = this.state,
            dataSource = _state.dataSource,
            configColumns = _state.configColumns;

        if (record.showConfigDisabled) {
            // 移动被合并列
            if (moveType == 'up') {
                var _ref2 = [dataSource[index - 1], dataSource[index]]; //上移一行

                dataSource[index] = _ref2[0];
                dataSource[index - 1] = _ref2[1];
            } else if (moveType == 'down') {
                var _ref3 = [dataSource[index + 1], dataSource[index]]; //下移一行

                dataSource[index] = _ref3[0];
                dataSource[index + 1] = _ref3[1];
            }
            // 找到对应的合并列
            var combineColumn = _.find(configColumns, ['dataIndex', record.refRootDataIndex]);
            if (combineColumn) {
                var currentNode, preNode, nextNode;
                var _index = _.findIndex(configColumns, ['dataIndex', record.refDataIndex]);
                if (moveType === 'up') {
                    currentNode = TreeUtils.findWithPropName(combineColumn.titleGroup, 'refDataIndex', dataSource[index].refDataIndex, true, true);
                    preNode = TreeUtils.findWithPropName(combineColumn.titleGroup, 'refDataIndex', dataSource[index - 1].refDataIndex, true, true);
                    var _ref4 = [configColumns[_index], configColumns[_index - 1]];
                    configColumns[_index - 1] = _ref4[0];
                    configColumns[_index] = _ref4[1];

                    if (currentNode && currentNode.length > 0 && preNode && preNode.length > 0) {
                        this._exChangeTitleGroupElement(combineColumn.titleGroup, currentNode[0], preNode[0]);
                    }
                } else if (moveType === 'down') {
                    currentNode = TreeUtils.findWithPropName(combineColumn.titleGroup, 'refDataIndex', dataSource[index].refDataIndex, true, true);
                    nextNode = TreeUtils.findWithPropName(combineColumn.titleGroup, 'refDataIndex', dataSource[index + 1].refDataIndex, true, true);
                    var _ref5 = [configColumns[_index + 1], configColumns[_index]];
                    configColumns[_index] = _ref5[0];
                    configColumns[_index + 1] = _ref5[1];

                    if (currentNode && currentNode.length > 0 && nextNode && nextNode.length > 0) {
                        this._exChangeTitleGroupElement(combineColumn.titleGroup, currentNode[0], nextNode[0]);
                    }
                }
            }
        } else {
            // 移动普通列或多表头列
            if (moveType === 'up') {
                var preRecord = dataSource[index - 1];
                if (record.colCombine) {
                    // 移动合并列
                    if (preRecord.refDataIndex) {
                        var preColCombineIndex = _.findIndex(dataSource, ['colIndex', preRecord.refRootDataIndex]);
                        var preGroup = _.slice(dataSource, preColCombineIndex, index);
                        dataSource.splice(preColCombineIndex, preGroup.length);
                        var lastRefDataIndex = _.findLastIndex(dataSource, ['refRootDataIndex', record.colIndex]);
                        _.forEach(preGroup, function (row, index) {
                            dataSource.splice(lastRefDataIndex + index + 1, 0, preGroup[index]);
                        });
                    } else {
                        var lastGroupDSIndex = _.findLastIndex(dataSource, ['refRootDataIndex', record.colIndex]);
                        var column = _.find(configColumns, ['dataIndex', record.colIndex]);
                        var childLength = 0;
                        if (column && column.titleGroup && column.titleGroup.length) {
                            for (var i = 0; i < column.titleGroup.length; i++) {
                                childLength = childLength + column.titleGroup[i].children.length;
                            }
                        }
                        dataSource.splice(index - 1, 1);
                        dataSource.splice(lastGroupDSIndex, 0, preRecord);
                    }
                } else {
                    // 移动普通列
                    if (preRecord.refDataIndex) {
                        var combineColumnIndex = _.findIndex(dataSource, ['colIndex', preRecord.refRootDataIndex]);
                        dataSource.splice(index, 1);
                        dataSource.splice(combineColumnIndex, 0, record);
                    } else {
                        var _ref6 = [dataSource[index - 1], dataSource[index]];
                        dataSource[index] = _ref6[0];
                        dataSource[index - 1] = _ref6[1];
                    }
                }
            } else if (moveType === 'down') {
                var nextRecord = dataSource[index + 1];
                var lastRefDataIndex = _.findLastIndex(dataSource, ['refRootDataIndex', record.colIndex]);
                if (record.colCombine) {
                    // 移动合并列
                    nextRecord = dataSource[lastRefDataIndex + 1];
                    if (nextRecord.colCombine) {
                        var nextLastRefDataIndex = _.findLastIndex(dataSource, ['refRootDataIndex', nextRecord.colIndex]);
                        var nextGroup = _.slice(dataSource, lastRefDataIndex + 1, nextLastRefDataIndex + 1);
                        dataSource.splice(lastRefDataIndex + 1, nextGroup.length);
                        _.forEach(nextGroup, function (row, rowIndex) {
                            dataSource.splice(index + rowIndex, 0, nextGroup[rowIndex]);
                        });
                    } else {
                        dataSource.splice(lastRefDataIndex + 1, 1);
                        dataSource.splice(index, 0, nextRecord);
                    }
                } else {
                    // 移动普通列
                    if (nextRecord.colCombine) {
                        var nextLastRefDataIndex = _.findLastIndex(dataSource, ['refRootDataIndex', nextRecord.colIndex]);
                        dataSource.splice(index, 1);
                        dataSource.splice(nextLastRefDataIndex, 0, record);
                    } else {
                        var _ref7 = [dataSource[index + 1], dataSource[index]];
                        dataSource[index] = _ref7[0];
                        dataSource[index + 1] = _ref7[1];
                    }
                }
            }
            configColumns = this.sortColumns(dataSource, configColumns);
        }
        this.setState({
            dataSource: dataSource,
            configColumns: configColumns
        });
    },
    _renderColumnOrder: function _renderColumnOrder(text, record, index) {
        var dataSource = this.state.dataSource;

        if (!dataSource || dataSource.length == 0) {
            return;
        }
        var cellViews = [];
        var firstRow = index === 0;
        var lastRow = index === dataSource.length - 1;
        var preRow = firstRow ? null : dataSource[index - 1];
        var nextRow = lastRow ? null : dataSource[index + 1];
        var upButton = React.createElement(
            YYCol,
            { span: '12' },
            React.createElement(YYButton, { icon: 'up', ghost: true, dashed: true, title: '\u4E0A\u79FB',
                onClick: this._handleMove.bind(null, record, index, 'up') })
        );
        var downButton = React.createElement(
            YYCol,
            { span: '12' },
            React.createElement(YYButton, { icon: 'down', ghost: true, dashed: true, title: '\u4E0B\u79FB',
                onClick: this._handleMove.bind(null, record, index, 'down') })
        );
        if (record.colFixed && record.colFixed !== 'none') {
            // 冻结列
            if (preRow && preRow.colFixed && preRow.colFixed !== 'none') {
                cellViews.push(upButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
            if (nextRow && nextRow.colFixed && nextRow.colFixed !== 'none') {
                cellViews.push(downButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
        } else if (record.refDataIndex) {
            // 多表头的被合并列(被合并列只能组内移动,不能与合并列移动顺序)
            if (record.refDataIndex === record.refRootDataIndex) {
                return;
            }
            if (preRow && preRow.refDataIndex && preRow.parentName === record.parentName && preRow.refRootDataIndex === record.refRootDataIndex && preRow.refRootDataIndex !== preRow.refDataIndex) {
                cellViews.push(upButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
            if (nextRow && nextRow.refDataIndex && nextRow.parentName === record.parentName && nextRow.refRootDataIndex === record.refRootDataIndex && nextRow.refRootDataIndex !== nextRow.refDataIndex) {
                cellViews.push(downButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
        } else {
            if (preRow && (!preRow.colFixed || preRow.colFixed === 'none')) {
                cellViews.push(upButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
            if (nextRow && (!nextRow.colFixed || nextRow.colFixed === 'none')) {
                cellViews.push(downButton);
            } else {
                cellViews.push(React.createElement(YYCol, { span: '12' }));
            }
        }
        return React.createElement(
            YYRow,
            null,
            cellViews
        );
    },
    _renderColumnShow: function _renderColumnShow(text, record, index) {
        if (record.colFixed && record.colFixed !== 'none') {
            //固定列
            return "固定显示";
        } else if (record.showConfigDisabled == true) {
            return React.createElement(
                'span',
                { title: '\u591A\u8868\u5934\u5217\u4E0D\u652F\u6301\u9690\u85CF' },
                '\u56FA\u5B9A\u663E\u793A'
            );
        } else {
            //非固定列
            return React.createElement(YYSwitch, { defaultChecked: record.colShow, checkedChildren: '\u662F', unCheckedChildren: '\u5426',
                onChange: this._onCellChange.bind(null, record, index, 'colShow') });
        }
    },
    _renderColumnWidth: function _renderColumnWidth(text, record, index) {
        if (record.colCombine == true) {
            return "自适应宽度";
        } else {
            return React.createElement(YYInputNumber, { placeholder: '<\u9ED8\u8BA4>', defaultValue: record.colWidth,
                onChange: this._onCellChange.bind(null, record, index, 'colWidth') });
        }
    },

    _renderColumnFixed: function _renderColumnFixed(text, record, index) {
        // 多表头暂不支持冻结
        if (record.colCombine == true || record.showConfigDisabled == true) {
            return React.createElement(
                'span',
                { title: '\u591A\u8868\u5934\u5217\u4E0D\u80FD\u8FDB\u884C\u51BB\u7ED3' },
                '\u4E0D\u51BB\u7ED3'
            );
        } else {
            return React.createElement(
                Select,
                { key: record.colIndex + "_" + index, defaultValue: record.colFixed ? record.colFixed : 'none',
                    onChange: this._onCellChange.bind(null, record, index, 'colFixed') },
                React.createElement(
                    Option,
                    { value: 'none' },
                    '\u4E0D\u51BB\u7ED3'
                ),
                React.createElement(
                    Option,
                    { value: 'left' },
                    '\u5DE6\u51BB\u7ED3'
                ),
                React.createElement(
                    Option,
                    { value: 'right' },
                    '\u53F3\u51BB\u7ED3'
                )
            );
        }
    },

    _onEnableTableHeight: function _onEnableTableHeight(checked) {
        var form = this.props.form;
        if (form) {
            form.setFieldsValue({ enableTableHeight: checked, tableHeight: null });
        }
        this.setState({ disableTableHeight: !checked });
    },

    render: function render() {
        var cls = this.className();
        var dataSource = this.state.dataSource;
        var columns = [
        // {
        //     title: '键值', isShow: false, dataIndex: 'colIndex', key: 'colIndex', width: 150
        // },
        /*{
         title:'固定',isShow:false,dataIndex:'colFixed',key:'colFixed'
         },*/
        {
            title: '列名', titleAlign: 'center', dataIndex: 'colName', key: 'colName'
        }, {
            title: '宽度',
            titleAlign: 'center',
            align: 'center',
            width: 100,
            dataIndex: 'colWidth',
            key: 'colWidth',
            render: this._renderColumnWidth
        }, {
            title: '固定冻结',
            titleAlign: 'center',
            align: 'center',
            width: 100,
            dataIndex: 'colFixed',
            key: 'colFixed',
            render: this._renderColumnFixed
        }, {
            title: '显示',
            titleAlign: 'center',
            align: 'center',
            width: 80,
            dataIndex: 'colShow',
            key: 'colShow',
            render: this._renderColumnShow
        }, {
            title: '顺序',
            titleAlign: 'center',
            dataIndex: 'order',
            key: 'order',
            width: 100,
            render: this._renderColumnOrder
        }];
        var footer = React.createElement(
            YYRow,
            null,
            React.createElement(
                YYButton,
                { type: 'warning', onClick: this._handleRevert },
                '\u8FD8\u539F\u9ED8\u8BA4'
            ),
            React.createElement(
                YYButton,
                { ghost: true, onClick: this._handleCancel },
                '\u53D6\u6D88'
            ),
            React.createElement(
                YYButton,
                { type: 'primary', onClick: this._handleOk },
                '\u786E\u5B9A'
            )
        );
        var getFieldProps = this.props.form.getFieldProps;

        var formItemSpan = {
            labelCol: { span: 10 },
            wrapperCol: { span: 10 }
        };
        var enableTableHeight = this.state.configScroll && this.state.configScroll["y"] != false;
        return React.createElement(
            YYModal,
            { title: '\u81EA\u5B9A\u4E49\u5217\u914D\u7F6E', onOk: this._handleOk, onCancel: this._handleCancel, visible: this.props.visible,
                width: 600, maskClosable: false, footer: footer },
            React.createElement(
                YYForm,
                null,
                React.createElement(
                    YYRow,
                    null,
                    React.createElement(
                        YYCol,
                        { span: 12 },
                        React.createElement(
                            YYFormItem,
                            _extends({}, formItemSpan, { label: '\u8868\u683C\u9AD8\u5EA6\u9650\u5236', labelHelp: '\u5F53\u8868\u683C\u5185\u5BB9\u8D85\u8FC7\u6307\u5B9A\u9AD8\u5EA6\u65F6,\u5C06\u51FA\u73B0\u5782\u76F4\u6EDA\u52A8\u6761' }),
                            React.createElement(YYSwitch, _extends({}, getFieldProps('enableTableHeight', { initialValue: enableTableHeight }), {
                                checkedChildren: '\u5F00',
                                unCheckedChildren: '\u5173',
                                defaultChecked: enableTableHeight,
                                onChange: this._onEnableTableHeight
                            }))
                        )
                    ),
                    React.createElement(
                        YYCol,
                        { span: 12 },
                        React.createElement(
                            YYFormItem,
                            _extends({}, formItemSpan, { label: '\u9650\u5236\u9AD8\u5EA6' }),
                            React.createElement(YYInputNumber, _extends({}, getFieldProps('tableHeight', {
                                initialValue: this.state.configScroll && !_.isEmpty(this.state.configScroll) ? this.state.configScroll["y"] : null
                            }), { disabled: this.state.disableTableHeight
                            }))
                        )
                    )
                )
            ),
            React.createElement(Table, { ref: 'configTable', dataSource: dataSource, columns: columns, bordered: true, checkable: false,
                pagination: false, size: 'small',
                className: cls })
        );
    }
});
module.exports = YYForm.create()(YYColumnConfig);