'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * 重写rc-table组件相关实现 by dio
 */
var React = require('react');
var ReactDOM = require('react-dom');
var RcTable = require('rc-table');
var TableRow = require('rc-table/lib/TableRow');

var _require = require('rc-table/lib/utils'),
    measureScrollbar = _require.measureScrollbar,
    debounce = _require.debounce;

var addEventListener = require('rc-util/lib/Dom/addEventListener');
var shallowequal = require('shallowequal');
var scrollIntoView = require('dom-scroll-into-view');
var _ = require('lodash');

//求三个数的最大值
function getMax(a, b, c) {
    return a > b ? a > c ? a : c : b > c ? b : c;
}

//add function by zhuzj
RcTable.prototype._getCurrentCenterColumns = function () {
    //获取中间表格需要展示的列信息（即过滤掉了左右固定列信息）
    return this.getCurrentColumns().filter(function (column) {
        return !column.fixed;
    });
};
RcTable.prototype._getColGroup = function (columns, fixed) {
    var cols = [];
    if (this.props.expandIconAsCell && fixed !== 'right') {
        cols.push(React.createElement('col', {
            className: this.props.prefixCls + '-expand-icon-col',
            key: 'rc-table-expand-icon-col'
        }));
    }
    // cols = cols.concat((columns || this.props.columns).map(c => {//modify by zhuzj
    cols = cols.concat((columns || this._getCurrentCenterColumns()).map(function (c) {
        var colStyle = { width: c.width, minWidth: c.width };
        if (c.key === 'selection-column') {
            //勾选框列
            colStyle.width = colStyle.width || '60px';
            colStyle.minWidth = colStyle.minWidth || '60px';
        } else if (c.key === 'rowNum') {
            //序号列
            colStyle.width = colStyle.width || '50px';
            colStyle.minWidth = colStyle.minWidth || '50px';
        } else {}
        return React.createElement('col', { key: c.key, style: colStyle });
    }));
    return React.createElement(
        'colgroup',
        null,
        cols
    );
};
RcTable.prototype._getHeader = function (columns, fixed) {
    var _props = this.props,
        showHeader = _props.showHeader,
        expandIconAsCell = _props.expandIconAsCell,
        prefixCls = _props.prefixCls;

    var ths = [];
    if (expandIconAsCell && fixed !== 'right') {
        ths.push({
            key: 'rc-table-expandIconAsCell',
            className: prefixCls + '-expand-icon-th',
            title: ''
        });
    }
    // ths = ths.concat(columns || this.getCurrentColumns()).map(c => {//modify by zhuzj
    ths = ths.concat(columns || this._getCurrentCenterColumns()).map(function (c) {
        if (c.colSpan !== 0) {
            return React.createElement(
                'th',
                { key: c.key, colSpan: c.colSpan, className: c.className || '' },
                c.title
            );
        }
    });
    var fixedColumnsHeadRowsHeight = this.state.fixedColumnsHeadRowsHeight;

    var trStyle = fixedColumnsHeadRowsHeight[0] && columns ? {
        height: fixedColumnsHeadRowsHeight[0]
    } : null;
    return showHeader ? React.createElement(
        'thead',
        { className: prefixCls + '-thead' },
        React.createElement(
            'tr',
            { style: trStyle },
            ths
        )
    ) : null;
};
//add by zhuzj 渲染空数据内容视图
RcTable.prototype._renderEmptyText = function (columns, fixed) {
    var _props2 = this.props,
        emptyView = _props2.emptyView,
        prefixCls = _props2.prefixCls;

    var tdProps = {};
    var tdView = null;
    if (fixed) {
        tdProps.dangerouslySetInnerHTML = { __html: '&nbsp;' }; //空格字符占位
    } else {
        tdView = typeof emptyView === 'function' ? emptyView(columns, fixed) : fixed ? null : emptyView;
    }
    return React.createElement(
        'tr',
        { className: prefixCls + '-emptyview' },
        React.createElement(
            'td',
            _extends({ className: prefixCls + '-placeholder', colSpan: columns ? columns.length : 0 }, tdProps),
            tdView
        )
    );
};
//rowIndex-累计行索引（注意：children结构的树表数据）
RcTable.prototype._getRowsByData = function (data, visible, indent, columns, fixed, rowIndex) {
    var props = this.props;
    var childrenColumnName = props.childrenColumnName;
    var expandedRowRender = props.expandedRowRender;
    var fixedColumnsBodyRowsHeight = this.state.fixedColumnsBodyRowsHeight;

    var rst = [];
    var rowClassName = props.rowClassName;
    var rowRef = props.rowRef;
    var expandedRowClassName = props.expandedRowClassName;
    var needIndentSpaced = props.data.some(function (record) {
        return record[childrenColumnName];
    });
    var onRowClick = props.onRowClick;
    var isAnyColumnsFixed = this.isAnyColumnsFixed();

    var expandIconAsCell = fixed !== 'right' ? props.expandIconAsCell : false;
    var expandIconColumnIndex = fixed !== 'right' ? props.expandIconColumnIndex : -1;
    //add by zhuzj
    var rowColumns = columns || this._getCurrentCenterColumns();
    if (props.expandIconColumnIndex == -1) {
        var allColumns = this.getCurrentColumns() || [];
        //获取勾选列|序号列以外的第一个显示列
        var firstColumnIndex = _.findIndex(allColumns, function (col) {
            return col.key !== 'selection-column' && col.key !== 'rowNum' && col.isShow !== false;
        });
        var firstColumn = firstColumnIndex > -1 ? allColumns[firstColumnIndex] : null;
        if (firstColumn) {
            if (firstColumn.fixed !== undefined && firstColumn.fixed !== 'right') {
                //第一个显示列为左侧固定列
                if (fixed) {
                    //则在渲染固定列时显示“+”图标
                    expandIconColumnIndex = firstColumnIndex;
                }
            } else {
                //第一个显示列为非固定列
                if (fixed === undefined) {
                    //则在渲染中间非固定列时显示“+”图标
                    //注意排除掉勾选列|序号列为固定列的情况
                    var selectionColumn = _.find(allColumns, ['key', 'selection-column']);
                    var rowNumColumn = _.find(allColumns, ['key', 'rowNum']);
                    if (selectionColumn && selectionColumn.fixed) firstColumnIndex--;
                    if (rowNumColumn && rowNumColumn.fixed) firstColumnIndex--;
                    expandIconColumnIndex = firstColumnIndex;
                }
            }
        }
    }

    //add by zhuzj
    if (indent == 0 && (!data || !data.length)) {
        //表树结构层级大于0的情况无需处理
        return { views: this._renderEmptyText(rowColumns, fixed), rowIndex: rowIndex };
    }

    for (var i = 0; i < data.length; i++) {
        var record = data[i];
        var key = this.getRowKey(record, i);
        var childrenColumn = record[childrenColumnName];
        var isRowExpanded = this.isRowExpanded(record);
        var expandedRowContent = void 0;
        if (expandedRowRender && isRowExpanded) {
            expandedRowContent = expandedRowRender(record, i);
        }
        var className = rowClassName(record, i);
        if (this.state.currentHoverKey === key) {
            className += ' ' + props.prefixCls + '-row-hover';
        }

        var onHoverProps = {};
        if (isAnyColumnsFixed) {
            onHoverProps.onHover = this.handleRowHover;
        }

        //修正：采用rowIndex方式解决，未处理children树表结构的情况 by zhuzj
        //修正：不是固定列的情况，去掉了fixed判断 by chenlizan
        var style = rowIndex < fixedColumnsBodyRowsHeight.length && fixedColumnsBodyRowsHeight[rowIndex] ? {
            height: fixedColumnsBodyRowsHeight[rowIndex]
        } : {};
        //修正：提供表格唯一标识，以保证行与所属表格的明确关系
        className += ' ' + this.props.ownerTableId;

        rst.push(React.createElement(TableRow, _extends({
            indent: indent,
            indentSize: props.indentSize,
            needIndentSpaced: needIndentSpaced,
            className: className,
            record: record,
            expandIconAsCell: expandIconAsCell,
            onDestroy: this.onRowDestroy,
            index: i,
            visible: visible,
            onExpand: this.onExpanded,
            expandable: childrenColumn || expandedRowRender,
            expanded: isRowExpanded,
            prefixCls: props.prefixCls + '-row',
            childrenColumnName: childrenColumnName
            /*modify by zhuzj columns={ columns||this.getCurrentColumns()}*/
            , columns: rowColumns,
            expandIconColumnIndex: expandIconColumnIndex,
            onRowClick: onRowClick,
            style: style
        }, onHoverProps, {
            key: key,
            hoverKey: key,
            ref: rowRef(record, i)
        })));

        var subVisible = visible && isRowExpanded;

        if (expandedRowContent && isRowExpanded) {
            rst.push(this.getExpandedRow(key, expandedRowContent, subVisible, expandedRowClassName(record, i), fixed));
        }
        rowIndex = rowIndex + 1; //zhuzj：注意在遍历子集前累加索引值
        if (childrenColumn) {
            var childrenRows = this._getRowsByData(childrenColumn, subVisible, indent + 1, columns, fixed, rowIndex);
            rst = rst.concat(childrenRows.views);
            rowIndex = childrenRows.rowIndex;
        }
    }
    return { views: rst, rowIndex: rowIndex };
};

RcTable.prototype._getRows = function (columns, fixed) {
    var rows = this._getRowsByData(this.state.data, true, 0, columns, fixed, 0);
    return rows.views;
};
RcTable.prototype._getLeftFixedTable = function () {
    var columns = this.props.columns;

    var fixedColumns = columns.filter(function (column) {
        return column.fixed === 'left' || column.fixed === true;
    });
    return this._getTable({
        columns: fixedColumns,
        fixed: 'left'
    });
};
RcTable.prototype._getRightFixedTable = function () {
    var columns = this.props.columns;

    var fixedColumns = columns.filter(function (column) {
        return column.fixed === 'right';
    });
    return this._getTable({
        columns: fixedColumns,
        fixed: 'right'
    });
};
RcTable.prototype._renderTable = function () {
    var hasHead = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    var hasBody = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    var hasBottom = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    var options = arguments[3];
    var columns = options.columns,
        fixed = options.fixed;

    var tableStyle = {};
    var _props3 = this.props,
        prefixCls = _props3.prefixCls,
        _props3$scroll = _props3.scroll,
        scroll = _props3$scroll === undefined ? {} : _props3$scroll,
        getBodyWrapper = _props3.getBodyWrapper,
        getInnerFilters = _props3.getInnerFilters,
        getInnerTotals = _props3.getInnerTotals;

    var tableClassName = prefixCls + '-fixed';
    if (!columns && scroll.x) {
        // not set width, then use content fixed width
        if (scroll.x === true) {
            tableStyle.tableLayout = 'fixed';
        } else {
            tableStyle.width = scroll.x;
        }
    }

    //add by zhuzj 追加固定列宽度计算，解决设置了固定列的width，表格被内容撑长的问题
    if (fixed && columns) {
        var fixedWidth = 0;
        columns.map(function (column) {
            if (column.key === 'selection-column') {
                //勾选框列
                fixedWidth += 60;
            } else {
                if (column.isShow !== false && column.width) {
                    fixedWidth += parseInt(column.width);
                }
            }
        });
        tableStyle.width = fixedWidth;
    }
    var tableBody = hasBody ? getBodyWrapper(React.createElement(
        'tbody',
        { className: prefixCls + '-tbody' },
        this._getRows(columns, fixed)
    ), columns, fixed, fixed ? undefined : this._getCurrentCenterColumns()) : null; //追加getBodyWrapper追加columns,fixed参数 add by dio
    var innerFiltersViews = null;
    if (hasHead && typeof getInnerFilters == 'function') {
        innerFiltersViews = getInnerFilters(columns, fixed, fixed ? undefined : this._getCurrentCenterColumns());
    }
    var InnerTotalsViews = null;
    if (typeof getInnerTotals == 'function') {
        InnerTotalsViews = getInnerTotals(columns, fixed, fixed ? undefined : this._getCurrentCenterColumns());
    }
    return React.createElement(
        'table',
        { className: tableClassName, style: tableStyle },
        this._getColGroup(columns, fixed),
        hasHead ? this._getHeader(columns, fixed) : null,
        innerFiltersViews,
        tableBody,
        hasBottom ? InnerTotalsViews : null
    );
};
RcTable.prototype._getTable = function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var columns = options.columns,
        fixed = options.fixed;
    var _props4 = this.props,
        prefixCls = _props4.prefixCls,
        _props4$scroll = _props4.scroll,
        scroll = _props4$scroll === undefined ? {} : _props4$scroll,
        bodyStyle = _props4.bodyStyle,
        useFixedHeader = _props4.useFixedHeader,
        getInnerTotals = _props4.getInnerTotals;

    var _bodyStyle = _.assign({}, bodyStyle);
    var headStyle = {};
    // let scrollbarWidth = 0;
    if (scroll.x || columns) {
        _bodyStyle.overflowX = _bodyStyle.overflowX || 'auto';
    }

    if (this.isAnyColumnsFixed()) {
        useFixedHeader = true; //存在固定列则使用固定表头
    }

    if (scroll.y) {
        useFixedHeader = true; //启用了表格垂直高度限制（滚动条）则使用固定表头
        // maxHeight will make fixed-Table scrolling not working
        // so we only set maxHeight to body-Table here

        // _bodyStyle.height = _bodyStyle.height || scroll.y;
        _bodyStyle.maxHeight = _bodyStyle.maxHeight || scroll.y;
        // _bodyStyle.overflowY = _bodyStyle.overflowY || 'scroll';

        // Add negative margin bottom for scroll bar overflow bug
        // scrollbarWidth = measureScrollbar();
        // if (scrollbarWidth > 0) {
        //     (fixed ? _bodyStyle : headStyle).marginBottom = `-${scrollbarWidth}px`;
        //     (fixed ? _bodyStyle : headStyle).paddingBottom = '0px';
        // }

        // if(fixed){//渲染固定列表格
        // }else{//渲染中间表格
        //     if(this.isAnyColumnsRightFixed()){
        //         // 中间区域出现垂直滚动条时才处理（已在YYTable.syncFixedScrollWidth方法处理）
        //         _bodyStyle.marginRight =`-${scrollbarWidth}px`;
        //     }
        // }
    }

    //add by zhuzj 追加固定列宽度计算，解决设置了固定列的width，表格被内容撑长的问题
    // let fixedWidth = 0;
    // if(fixed&&columns){
    //     columns.map(column => {
    //         if(column.key ==='selection-column'){//勾选框列
    //             fixedWidth +=60;
    //         }else{
    //             if(column.isShow!==false && column.width){
    //                 fixedWidth += parseInt(column.width);
    //             }
    //         }
    //     });
    // }

    var headTable = void 0;
    if (useFixedHeader) {
        headTable = React.createElement(
            'div',
            {
                className: prefixCls + '-header',
                ref: columns ? null : 'headTable',
                style: headStyle,
                onMouseOver: this.detectScrollTarget,
                onTouchStart: this.detectScrollTarget
                // onScroll={this.handleBodyScroll}
            },
            this._renderTable(true, false, false, { columns: columns, fixed: fixed })
        );
    }

    var bodyTable = React.createElement(
        'div',
        {
            className: prefixCls + '-body',
            style: _bodyStyle,
            ref: 'bodyTable',
            onMouseOver: this.detectScrollTarget,
            onTouchStart: this.detectScrollTarget,
            onScroll: this._handleBodyScroll.bind(this)
        },
        this._renderTable(!useFixedHeader, true, false, { columns: columns, fixed: fixed })
    );

    var bottomTable = React.createElement(
        'div',
        {
            className: prefixCls + '-bottom',
            ref: columns ? null : 'bottomTable',
            style: useFixedHeader ? headStyle : { overflow: "hidden" },
            onMouseOver: this.detectScrollTarget,
            onTouchStart: this.detectScrollTarget
        },
        this._renderTable(false, false, true, { columns: columns, fixed: fixed })
    );

    if (columns && columns.length) {
        var refName = void 0;
        if (columns[0].fixed === 'left' || columns[0].fixed === true) {
            refName = 'fixedColumnsBodyLeft';
        } else if (columns[0].fixed === 'right') {
            refName = 'fixedColumnsBodyRight';
        }
        var _bInnerStyle = _.assign({}, bodyStyle);
        if (fixed) {
            _bInnerStyle.height = 'auto';
            _bInnerStyle.maxHeight = _bInnerStyle.maxHeight || scroll.y;
            // 中间区域出现水平滚动条时才处理（已在YYTable.syncFixedScrollWidth方法处理）
            // _bInnerStyle.paddingBottom = `${scrollbarWidth}px`;
        }
        //add by zhuzj 修正空数据时固定列宽度不对齐的问题
        var _bOuterStyle = {};
        // if(fixed){
        // if(fixed==='right'){//修正右侧固定列显示滚动条宽度未参与计算的问题
        //     _bOuterStyle.width = fixedWidth+(scroll.y?scrollbarWidth:0);
        // }else{
        //     _bOuterStyle.width = fixedWidth;
        // }
        // }
        //fix by zhuzj 解决固定表头下左右冻结列滚动条问题，_bStyle样式调整及作用到body-inner元素上
        bodyTable = React.createElement(
            'div',
            {
                className: prefixCls + '-body-outer',
                style: _bOuterStyle
            },
            React.createElement(
                'div',
                {
                    className: prefixCls + '-body-inner',
                    style: _bInnerStyle,
                    ref: refName,
                    onMouseOver: this.detectScrollTarget,
                    onTouchStart: this.detectScrollTarget,
                    onScroll: this._handleBodyScroll.bind(this)
                },
                this._renderTable(!useFixedHeader, true, false, { columns: columns, fixed: fixed })
            )
        );
    }
    //todo chenlizan begin
    // let bottomTable = null;
    // if (typeof getInnerTotals == 'function') {
    //     bottomTable = getInnerTotals(columns, fixed, fixed ? undefined : this._getCurrentCenterColumns());
    // }
    //todo chenlizan end
    var _views = [];
    if (headTable) _views.push(headTable);
    if (bodyTable) _views.push(bodyTable);
    if (bottomTable) _views.push(bottomTable);
    return React.createElement(
        'span',
        null,
        _views
    );
};
RcTable.prototype._handleBodyScroll = function (e) {

    // Prevent scrollTop setter trigger onScroll event
    // http://stackoverflow.com/q/1386696
    if (this.scrollTarget && e.target !== this.scrollTarget && this.scrollTarget.className !== 'ant-table-header') {
        return;
    }
    var _props$scroll = this.props.scroll;
    var scroll = _props$scroll === undefined ? {} : _props$scroll;
    var _refs = this.refs;
    var headTable = _refs.headTable;
    var bodyTable = _refs.bodyTable;
    var bottomTable = _refs.bottomTable;
    var fixedColumnsBodyLeft = _refs.fixedColumnsBodyLeft;
    var fixedColumnsBodyRight = _refs.fixedColumnsBodyRight;

    if (scroll.x) {
        if (e.target === bodyTable) {
            if (headTable) headTable.scrollLeft = e.target.scrollLeft;
            if (bottomTable) bottomTable.scrollLeft = e.target.scrollLeft;
        } else if (e.target === headTable && bodyTable) {
            bodyTable.scrollLeft = e.target.scrollLeft;
        }
        if (e.target.scrollLeft === 0) {
            this.setState({ scrollPosition: 'left' });
        } else if (e.target.scrollLeft + 1 >= e.target.children[0].getBoundingClientRect().width - e.target.getBoundingClientRect().width) {
            this.setState({ scrollPosition: 'right' });
        } else if (this.state.scrollPosition !== 'middle') {
            this.setState({ scrollPosition: 'middle' });
        }
    }
    if (scroll.y) {
        if (fixedColumnsBodyLeft && e.target !== fixedColumnsBodyLeft) {
            fixedColumnsBodyLeft.scrollTop = e.target.scrollTop;
        }
        if (fixedColumnsBodyRight && e.target !== fixedColumnsBodyRight) {
            fixedColumnsBodyRight.scrollTop = e.target.scrollTop;
        }
        if (bodyTable && e.target !== bodyTable) {
            bodyTable.scrollTop = e.target.scrollTop;
        }
    }
};
//add by 重置行高度，以解决编辑表格数据内容的行高被数据撑开后，当数据减少时无法缩回高度的问题
RcTable.prototype.resetRowsHeight = function (callback) {
    var fixedColumnsBodyRowsHeight = this.state.fixedColumnsBodyRowsHeight.map(function () {
        return 'auto';
    });
    this.setState({
        fixedColumnsBodyRowsHeight: fixedColumnsBodyRowsHeight
    }, callback);
};
RcTable.prototype._syncFixedTableRowHeight = function () {
    var _this = this;

    var _props5 = this.props,
        prefixCls = _props5.prefixCls,
        ownerTableId = _props5.ownerTableId;
    // by chenlizan begin

    if (this._calledComponentWillUnmount) return;
    var tableDom = ReactDOM.findDOMNode(this);
    var fixedLeftRowsHeight = tableDom.querySelectorAll('.' + prefixCls + '-fixed-left .' + prefixCls + '-row.' + ownerTableId);
    var fixedRightRowsHeight = tableDom.querySelectorAll('.' + prefixCls + '-fixed-right .' + prefixCls + '-row.' + ownerTableId);
    // by chenlizan end

    var headRows = this.refs.headTable ? this.refs.headTable.querySelectorAll('tr') : [];
    var bodyRows = this.refs.bodyTable.querySelectorAll('.' + prefixCls + '-center .' + prefixCls + '-row.' + ownerTableId) || [];
    var fixedColumnsHeadRowsHeight = [].map.call(headRows, function (row) {
        return row.getBoundingClientRect().height || 'auto';
    });
    // const fixedColumnsBodyRowsHeight = [].map.call(
    //     bodyRows, row => row.getBoundingClientRect().height || 'auto'
    // );
    // by chenlizan begin
    var fixedColumnsBodyRowsHeight = [].map.call(bodyRows, function (row, i) {
        return getMax(fixedLeftRowsHeight.length ? fixedLeftRowsHeight[i].getBoundingClientRect().height : 0, fixedRightRowsHeight.length ? fixedRightRowsHeight[i].getBoundingClientRect().height : 0, row.getBoundingClientRect().height);
    });
    // by chenlizan end
    if (shallowequal(this.state.fixedColumnsHeadRowsHeight, fixedColumnsHeadRowsHeight) && shallowequal(this.state.fixedColumnsBodyRowsHeight, fixedColumnsBodyRowsHeight)) {
        return;
    }
    clearTimeout(this.timer);
    this.timer = setTimeout(function () {
        _this.setState({
            fixedColumnsHeadRowsHeight: fixedColumnsHeadRowsHeight,
            fixedColumnsBodyRowsHeight: fixedColumnsBodyRowsHeight
        }, function () {
            var center = tableDom.querySelector('.ant-table-body');
            var select = tableDom.querySelector('.ant-table-center .yyui-table-row-selected');
            var left = tableDom.querySelector('.ant-table-fixed-left .ant-table-body-inner');
            var right = tableDom.querySelector('.ant-table-fixed-right .ant-table-body-inner');
            //如果在编辑态，先定位到编辑态的行位置。
            if (select) scrollIntoView(select, right ? right : center, {
                alignWithTop: true,
                onlyScrollIfNeeded: true,
                allowHorizontalScroll: false
            });
            //滚动条在最底部并且表格行高变化时，inner部分scrollTop数值不一致造成的表格没对齐。
            if (this.isAnyColumnsRightFixed()) {
                if (center && right && center.scrollTop !== right.scrollTop) {
                    center.scrollTop = right.scrollTop;
                }
                if (center && left && left.scrollTop !== right.scrollTop) {
                    left.scrollTop = right.scrollTop;
                }
            } else {
                if (center && left && center.scrollTop !== left.scrollTop) {
                    left.scrollTop = center.scrollTop;
                }
            }
        });
    });
};

RcTable.prototype.componentDidMount = function () {
    this.resetScrollY();
    this._syncFixedTableRowHeight();
    var isAnyColumnsFixed = this.isAnyColumnsFixed();
    if (isAnyColumnsFixed) {
        this.resizeEvent = addEventListener(window, 'resize', debounce(this._syncFixedTableRowHeight.bind(this), 150));
    }
};
RcTable.prototype.componentDidUpdate = function () {
    this._syncFixedTableRowHeight();
};
RcTable.prototype.render = function () {
    var props = this.props;
    var prefixCls = props.prefixCls;

    var className = props.prefixCls;
    if (props.className) {
        className += ' ' + props.className;
    }
    if (props.columnsPageRange) {
        className += ' ' + prefixCls + '-columns-paging';
    }
    if (props.useFixedHeader || this.isAnyColumnsFixed() || props.scroll && props.scroll.y) {
        className += ' ' + prefixCls + '-fixed-header';
    }
    className += ' ' + prefixCls + '-scroll-position-' + this.state.scrollPosition;

    var isTableScroll = this.isAnyColumnsFixed() || props.scroll.x || props.scroll.y;

    var contentClass = [prefixCls + '-content'];
    if (this.isAnyColumnsLeftFixed()) contentClass.push('has-fixed-left');
    if (this.isAnyColumnsRightFixed()) contentClass.push('has-fixed-right');
    return React.createElement(
        'div',
        { className: className, style: props.style },
        this.getTitle(),
        React.createElement(
            'div',
            { className: contentClass.join(' ') },
            this.isAnyColumnsLeftFixed() && React.createElement(
                'div',
                { className: prefixCls + '-fixed-left' },
                this._getLeftFixedTable()
            ),
            React.createElement(
                'div',
                { className: prefixCls + '-center ' + (isTableScroll ? prefixCls + '-scroll' : '') },
                this._getTable(),
                this.getFooter()
            ),
            this.isAnyColumnsRightFixed() && React.createElement(
                'div',
                { className: prefixCls + '-fixed-right' },
                this._getRightFixedTable()
            )
        )
    );
};
//exports["default"] = RcTable;
module.exports = RcTable;